# Copyright (c) 2015 EMC Corporation
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from sqlalchemy import Column, MetaData, String, Table


def upgrade(migrate_engine):
    meta = MetaData()
    meta.bind = migrate_engine

    backups = Table('backups', meta, autoload=True)
    temp_volume_id = Column('temp_volume_id', String(length=36))
    temp_snapshot_id = Column('temp_snapshot_id', String(length=36))

    backups.create_column(temp_volume_id)
    backups.update().values(temp_volume_id=None).execute()

    backups.create_column(temp_snapshot_id)
    backups.update().values(temp_snapshot_id=None).execute()
